<?php

namespace Survey\Employee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Employee\Models\Leavepay;

class LeavepayPolicy
{

    /**
     * Determine if the given user can view the leavepay.
     *
     * @param UserPolicy $user
     * @param Leavepay $leavepay
     *
     * @return bool
     */
    public function view(UserPolicy $user, Leavepay $leavepay)
    {
        if ($user->canDo('employee.leavepay.view') && $user->isAdmin()) {
            return true;
        }

        return $leavepay->user_id == user_id() && $leavepay->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leavepay.
     *
     * @param UserPolicy $user
     * @param Leavepay $leavepay
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employee.leavepay.create');
    }

    /**
     * Determine if the given user can update the given leavepay.
     *
     * @param UserPolicy $user
     * @param Leavepay $leavepay
     *
     * @return bool
     */
    public function update(UserPolicy $user, Leavepay $leavepay)
    {
        if ($user->canDo('employee.leavepay.edit') && $user->isAdmin()) {
            return true;
        }

        return $leavepay->user_id == user_id() && $leavepay->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leavepay.
     *
     * @param UserPolicy $user
     * @param Leavepay $leavepay
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Leavepay $leavepay)
    {
        return $leavepay->user_id == user_id() && $leavepay->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leavepay.
     *
     * @param UserPolicy $user
     * @param Leavepay $leavepay
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Leavepay $leavepay)
    {
        if ($user->canDo('employee.leavepay.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leavepay.
     *
     * @param UserPolicy $user
     * @param Leavepay $leavepay
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Leavepay $leavepay)
    {
        if ($user->canDo('employee.leavepay.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
